@@ -17,9 +17,11 @@ from cdp_backend.pipeline.mock_get_events import (
     get_events as get_test_deployment_events,
 )
 
-from cdp_scrapers.legistar_utils import LegistarScraper
-from cdp_scrapers.instances.portland import get_portland_events
+from cdp_scrapers.instances.houston import get_houston_events
 from cdp_scrapers.instances.atlanta import get_events as get_atlanta_events
+from cdp_scrapers.instances.lacity import LosAngelesScraper, get_lacity_events
+from cdp_scrapers.instances.portland import get_portland_events
+from cdp_scrapers.legistar_utils import LegistarScraper
 
 ###############################################################################
 
@@ -57,7 +59,9 @@ for submodule in iter_modules(__path__):
 # SCRAPER_FUNCTIONS[{python_municipality_slug}] = {function_callable}
 SCRAPER_FUNCTIONS["test_deployment"] = get_test_deployment_events
 SCRAPER_FUNCTIONS["portland"] = get_portland_events
+SCRAPER_FUNCTIONS["houston"] = get_houston_events
 SCRAPER_FUNCTIONS["atlanta"] = get_atlanta_events
+SCRAPER_FUNCTIONS[LosAngelesScraper.PYTHON_MUNICIPALITY_SLUG] = get_lacity_events
 
 # Set all scraper functions as exports of this module
 for python_municipality_slug, func in SCRAPER_FUNCTIONS.items():
