@@ -1,21 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import json
 import logging
 import re
-import json
-import requests
-import urllib3
 import warnings
+from datetime import datetime
+from pathlib import Path
 from typing import Dict, List, Optional
 from urllib.error import HTTPError, URLError
+from urllib.parse import parse_qs, quote_plus, urlsplit
 from urllib.request import urlopen
-from urllib.parse import urlsplit, parse_qs, quote_plus
-from pathlib import Path
-from datetime import datetime
 
+import requests
+import urllib3
 from bs4 import BeautifulSoup
-
 from cdp_backend.pipeline.ingestion_models import Person, Seat
 
 from ..legistar_utils import (
@@ -23,7 +22,7 @@ from ..legistar_utils import (
     LEGISTAR_SESSION_DATE,
     LegistarScraper,
 )
-from ..scraper_utils import str_simplified, parse_static_file
+from ..scraper_utils import parse_static_file, str_simplified
 from ..types import ContentURIs
 
 ###############################################################################
@@ -312,7 +311,10 @@ class SeattleScraper(LegistarScraper):
         # href attribute that contains videoid
 
         soup = BeautifulSoup(response, "html.parser")
-        for link in soup.find("div", class_="paginationContainer",).find_all(
+        for link in soup.find(
+            "div",
+            class_="paginationContainer",
+        ).find_all(
             "a",
             href=re.compile("videoid"),
             onclick=re.compile("loadJWPlayer"),
